# latest information earthquake indonesia
<b>This package informs about the latest earthquake from Meteorology Climatology and Geophysics Agency(BMKG)</b>

## HOW IT WORK?

<h3>This package can scrape from bmkg(bmkg.go.id)</h3> 
<br>
<b>This package uses technology from beautifulsoup4 and requests</b>

## HOW TO USE?
```
if __name__ == "__main__":
    print("Latest earthquake information")
    result = ekstrak()
    showdata(result)
```
